@@ -22,7 +22,7 @@ use Apache::Session::MySQL;
 use Apache::Session::Lock::MySQL;
 use Params::Validate qw( :all );
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -39,7 +39,7 @@ sub new {
 #----------------------------------------------------------------------------+
 # create( \%controller, $name, \%data )
 #
-# Create a new session within the database.  Return the session_id.
+# Create a new session within the database and set a web browser cookie.
 
 sub create {
     my ( $self, $c, $name, $data_ref )
@@ -50,6 +50,9 @@ sub create {
           { type => HASHREF }
           );
 
+    $self->error('Invalid session name')
+      unless ( $name =~ /^[\w]{20}$/ );
+
     my $dbh = $c->stash('DBH');     # use an existing connection
 
     # create table if it doesn't exist
@@ -97,28 +100,32 @@ sub create {
 }
 
 #----------------------------------------------------------------------------+
-# get( \%controller, $name )
+# get( \%controller, $arg )
 #
-# Return session data as a hash reference.
+# Takes the cookie unique identifier or session id as arguments.  Returns
+# the session data as a hash reference. 
 
 sub get {
-    my ( $self, $c, $name )
+    my ( $self, $c, $arg )
       = validate_pos( @_,
           { type => OBJECT  },
           { type => HASHREF },
           { type => SCALAR  }
           );
 
-    my $cookie = $c->plugin('Cookie')->get($name);
+    my $cookie = $c->plugin('Cookie')->get($arg);
 
-    my $session_id = ($cookie) ? $cookie : 'null';
+    my $id = ($cookie) ? $cookie : $arg;
+
+    $self->error('Malformed session identifier')
+      unless ( $id =~ /^[a-zA-Z]{32}$/ );
 
     my $dbh = $c->stash('DBH');     # use an existing connection
 
     my %session;
 
     eval {
-        tie %session, 'Apache::Session::MySQL', $session_id, {
+        tie %session, 'Apache::Session::MySQL', $id, {
             Handle     => $dbh,
             LockHandle => $dbh,
         };
@@ -136,12 +143,13 @@ sub get {
 }
 
 #----------------------------------------------------------------------------+
-# delete( \%controller, $name )
+# delete( \%controller, $arg )
 #
-# Delete an existing session.  Remove the referring cookie.
+# Takes the cookie unique identifier or session id as arguments.  Deletes
+# an existing session.
 
 sub delete {
-    my ( $self, $c, $name )
+    my ( $self, $c, $arg )
       = validate_pos( @_,
           { type => OBJECT  },
           { type => HASHREF },
@@ -150,9 +158,12 @@ sub delete {
 
     my $doc_root = $c->config->{apache_doc_root};
 
-    my $cookie = $c->plugin('Cookie')->get($name);
+    my $cookie = $c->plugin('Cookie')->get($arg);
 
-    my $id = ($cookie) ? $cookie : 'null';
+    my $id = ($cookie) ? $cookie : $arg;
+
+    $self->error('Malformed session identifier')
+      unless ( $id =~ /^[a-zA-Z]{32}$/ );
 
     my $dbh = $c->stash('DBH');     # use an existing connection
 
@@ -168,19 +179,20 @@ sub delete {
     unless ($@) {
         tied(%session)->delete;
 
-        $c->plugin('Cookie')->delete( $c, $name );
+        $c->plugin('Cookie')->delete( $c, $arg );
     }
 
     return;
 }
 
 #----------------------------------------------------------------------------+
-# update( \%controller, $name, \%data );
+# update( \%controller, $arg, \%data );
 #
-# Update existing session data.
+# Takes the cookie unique identifier or session id as arguments.  Updates
+# existing session data.
 
 sub update {
-    my ( $self, $c, $name, $data_ref )
+    my ( $self, $c, $arg, $data_ref )
       = validate_pos( @_,
           { type => OBJECT  },
           { type => HASHREF },
@@ -188,9 +200,14 @@ sub update {
           { type => HASHREF }
           );
 
-    my $cookie = $c->plugin('Cookie')->get($name);
+    my $doc_root = $c->config->{apache_doc_root};
 
-    my $id = ($cookie) ? $cookie : 'null';
+    my $cookie = $c->plugin('Cookie')->get($arg);
+
+    my $id = ($cookie) ? $cookie : $arg;
+
+    $self->error('Malformed session identifier')
+      unless ( $id =~ /^[a-zA-Z]{32}$/ );
 
     my $dbh = $c->stash('DBH');     # use an existing connection
 
@@ -219,7 +236,7 @@ sub update {
 #----------------------------------------------------------------------------+
 # id( \%controller, $name )
 #
-# Return the unique identifier for a given session.
+# Return the cookie unique identifier for a given session.
 
 sub id {
     my ( $self, $c, $name )
@@ -293,7 +310,7 @@ Perl one liner using CPAN.pm:
 
 Use of CPAN.pm in interactive mode:
 
-  $> perl -MCPAN -e shell
+  $ perl -MCPAN -e shell
   cpan> install Apache2::WebApp::Plugin::Session::MySQL
   cpan> quit
 
